import reclass_rs


def test_no_compose_node_name_compat():
    r = reclass_rs.Reclass(inventory_path="./tests/inventory-compose-node-name")
    r.set_compat_flag(reclass_rs.CompatFlag.ComposeNodeNameLiteralDots)
    assert not r.config.compose_node_name
    assert r.config.compatflags == {reclass_rs.CompatFlag.ComposeNodeNameLiteralDots}

    inv = r.inventory()

    assert set(inv.nodes.keys()) == {"a.1", "a", "d"}

    a1 = inv.nodes["a.1"].parameters["_reclass_"]["name"]
    assert a1["full"] == "a.1"
    assert a1["parts"] == ["a.1"]
    assert a1["path"] == "a.1"
    assert a1["short"] == "a.1"


def test_no_compose_node_name():
    r = reclass_rs.Reclass(inventory_path="./tests/inventory-compose-node-name")
    assert not r.config.compose_node_name
    assert r.config.compatflags == set()

    inv = r.inventory()

    assert set(inv.nodes.keys()) == {"a.1", "a", "d"}

    a1 = inv.nodes["a.1"].parameters["_reclass_"]["name"]
    assert a1["full"] == "a.1"
    assert a1["parts"] == ["a.1"]
    assert a1["path"] == "a.1"
    assert a1["short"] == "a.1"


def test_compose_node_name_compat():
    r = reclass_rs.Reclass.from_config_file(
        "./tests/inventory-compose-node-name", "reclass-config.yml"
    )
    r.set_compat_flag(reclass_rs.CompatFlag.ComposeNodeNameLiteralDots)
    assert r.config.compose_node_name
    assert r.config.compatflags == {reclass_rs.CompatFlag.ComposeNodeNameLiteralDots}

    inv = r.inventory()

    assert set(inv.nodes.keys()) == {
        "a.1",
        "a",
        "b.1",
        "c.1",
        "c._c.1",
        "d",
        "d1",
        "d2",
    }

    a1 = inv.nodes["a.1"].parameters["_reclass_"]["name"]
    assert a1["full"] == "a.1"
    assert a1["parts"] == ["a", "1"]
    assert a1["path"] == "a/1"
    assert a1["short"] == "1"


def test_compose_node_name():
    r = reclass_rs.Reclass.from_config_file(
        "./tests/inventory-compose-node-name", "reclass-config.yml"
    )
    assert r.config.compose_node_name
    assert r.config.compatflags == set()

    inv = r.inventory()

    assert set(inv.nodes.keys()) == {
        "a.1",
        "a",
        "b.1",
        "c.1",
        "c._c.1",
        "d",
        "d1",
        "d2",
    }

    a1 = inv.nodes["a.1"].parameters["_reclass_"]["name"]
    assert a1["full"] == "a.1"
    assert a1["parts"] == ["a.1"]
    assert a1["path"] == "a.1"
    assert a1["short"] == "a.1"



import reclass_rs
import pytest
import pathlib


def test_config_from_dict():
    config_options = {
        "nodes_uri": "targets",
        "classes_uri": "classes",
        "ignore_class_notfound": False,
        "compose_node_name": False,
    }
    c = reclass_rs.Config.from_dict("./tests/inventory", config_options)
    assert c is not None

    assert not c.ignore_class_notfound
    assert not c.compose_node_name

    expected_nodes_path = pathlib.Path("./tests/inventory/targets")
    expected_classes_path = pathlib.Path("./tests/inventory/classes")
    assert pathlib.Path(c.nodes_path) == expected_nodes_path
    assert pathlib.Path(c.classes_path) == expected_classes_path


def test_config_from_dict_non_default():
    config_options = {
        "nodes_uri": "targets",
        "classes_uri": "classes",
        "ignore_class_notfound": True,
        "ignore_class_notfound_regexp": ["foo", "bar"],
        "compose_node_name": True,
    }
    c = reclass_rs.Config.from_dict("./tests/inventory", config_options)
    assert c is not None

    assert c.ignore_class_notfound
    assert c.compose_node_name

    expected_nodes_path = pathlib.Path("./tests/inventory/targets")
    expected_classes_path = pathlib.Path("./tests/inventory/classes")
    assert pathlib.Path(c.nodes_path) == expected_nodes_path
    assert pathlib.Path(c.classes_path) == expected_classes_path

    assert c.ignore_class_notfound_regexp == ["foo", "bar"]



import pytest

import reclass_rs


def test_ignore_regexp_render_n1():
    r = reclass_rs.Reclass.from_config_file(
        "./tests/inventory-class-notfound-regexp", "reclass-config.yml"
    )
    assert r.config.ignore_class_notfound_regexp == ["service\\..*", ".*missing.*"]

    n1 = r.nodeinfo("n1")

    assert n1 is not None


def test_ignore_regexp_render_n2():
    r = reclass_rs.Reclass.from_config_file(
        "./tests/inventory-class-notfound-regexp", "reclass-config.yml"
    )
    assert r.config.ignore_class_notfound_regexp == ["service\\..*", ".*missing.*"]

    with pytest.raises(
        ValueError, match="Error while rendering n2: Class foo not found"
    ):
        n2 = r.nodeinfo("n2")


def test_ignore_regexp_update_config_render_n2():
    r = reclass_rs.Reclass.from_config_file(
        "./tests/inventory-class-notfound-regexp", "reclass-config.yml"
    )
    r.set_ignore_class_notfound_regexp([".*"])
    assert r.config.ignore_class_notfound_regexp == [".*"]

    n2 = r.nodeinfo("n2")
    assert n2 is not None



import reclass_rs
import pytest
import os
import pathlib


def test_import_new():
    r = reclass_rs.Reclass(
        "./tests/inventory",
        "targets",
        "classes",
        True,
    )
    invpath = pathlib.Path("./tests/inventory")
    assert r is not None
    assert r.config is not None
    assert pathlib.Path(r.config.inventory_path) == invpath
    assert pathlib.Path(r.config.nodes_path) == invpath / "targets"
    assert pathlib.Path(r.config.classes_path) == invpath / "classes"
    assert r.config.ignore_class_notfound

    assert r.nodes is not None
    assert r.classes is not None


def test_import_raises():
    with pytest.raises(ValueError) as exc:
        r = reclass_rs.Reclass("./inventory", "foo", "bar")

    assert "Error while discovering nodes" in str(exc.value)
